#!/bin/sh
# $Id: sastk_undo.sh,v 1.10 2001/01/25 12:19:13 mrgoblin Exp $

#############################################
#
# SAStk Hardening Script Uninstall
#
# For Slackware Linux 7.0 - 7.1
#
#############################################
# SAStk_undo 0.1
# Copyright (C) John Jenkins
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###########################

# Set default binary locations
. /etc/rc.d/rc.paths

ver="0.1"

${CLEAR}

###############
#Check for root
###############

if [ ! "${UID}" = "0" ]; then
    ${ECHO} -e "  You must be root to run the SAStk Undo script!! \a"
    ${ECHO} "  Please log in or \"su -\" to root."
    exit
fi

${CAT} << EOF
********************************************************************************
*             Welcome to the SAStk removal script version ${ver}
********************************************************************************

Checking System

Please wait

EOF

#################
# Set variables #
#################

export LOG="/var/log/sastk"
export logfile="${LOG}/sastk_undo.log"
export errlog="${LOG}/sastk_err.log"
export BKUP="${LOG}/backup"
export RC="/etc/rc.d"

##########################
# Check for SAStk Backup #
##########################

[ ! -d "${BKUP}" ] && ${ECHO} "${BKUP} not found!! Aborting Undo" && exit 1

#################
# Check version #
#################

if [ ! -f "/etc/slackware-version" ]; then
    ${ECHO} -e "\n/etc/slackware-version does NOT exist!!\n"
    ${ECHO} -e "\nAre you sure this is Slackware?\n"
    exit
fi

version=$(${CAT} /etc/slackware-version)

if [ "${version}" = "7.0.0" -o "${version}" = "7.1.0" ];then
    ${CAT} << EOF

We detect you are using Slackware ${version}.

System checks out okay ... Lets's go

EOF
else
    ${CAT} << EOF

SAStk does not support Slackware ${version} at this time.
Bug the developers until they include support for it.

EOF
    exit
fi

##############################
#Checking for single user mode
##############################

if [ "$(${RUNLEVEL} | ${AWK} '{print $2}')" != "1" ]; then
    ${ECHO} ""
    ${CLEAR} 
    quit=n
${CAT} << EOF
********************************************************************************
*                     SAStk removal script version ${ver}
********************************************************************************

This script should be run in single user mode
If you are in single user mode then we screwed up ... press < 1 > to continue
If you are not already in single user mode press < 2 > to enter this mode
EOF
    while [ "${quit}" = "n" ]; do
${CAT} << EOF

Choose an option from the list

1) I know what I'm doing continue in current mode
2) Enter single user mode
Q) Quit this script

EOF

        ${ECHO} -ne "Choose an option: .\b"
        read choice
        case ${choice} in
              1)       quit="y"; ${CLEAR}
                       ;;
              2)     [ -f /root/.bash_login ] && ${CP} "/root/.bash_login" "/root/.bash_login.bak"
                 CDIR=$(${PWD})
                  ${CAT} > /root/.bash_login <<EOF
#!/bin/sh
echo
if [ "\$(/sbin/runlevel | awk '{print \$2}')" = "1" ]; then
clear
echo
quit="n"
    while [ "\${quit}" = "n" ]; do
cat << !
********************************************************************************
*                     SAStk removal script version ${ver}
********************************************************************************

This is part of the SAStk removal script.
You should now be in Single user mode.
please choose an option from below.


1) Every thing seems okay.. continue with the removal
2) What the.... Stop this madness and don't let it happen again
Q) Just quit this I'll handle the rest myself

!
    echo -ne "Choose an Option: .\b"
    read choice
    case \${choice} in
        1)       quit="y"
                 cd ${CDIR}
                 ./sastk_undo.sh
                   ;;
        2)       [ -f /root/.bash_login.bak ] && mv "/root/.bash_login.bak" "/root/.bash_login" || rm "/root/.bash_log
in"
                 quit="y"
                 clear
                   ;;
      Q|q)       quit="y"
                 clear
                   ;;
        *)       echo -ne "Invalid choice!! \a\a"
                   ;;
     esac
   done
fi
EOF
       ${ECHO} "Switching to S Mode.  You will need to log back in as root."
       ${ECHO} "This script should continue automatically"
                       ${TELINIT} 1; exit 0
                       ;;
            Q|q)       ${CLEAR}; exit 1
                       ;;
              *)       ${ECHO} -ne "Invalid choice!! \a\a"
                       ;;
        esac
  done
fi


############
# Set PATH #
############

OLDPATH="${PATH}"
PATH=/sbin:/usr/sbin:/bin:/usr/bin


##################
# Start the work #
##################

${ECHO} '#########' >> ${logfile}
${ECHO} "$0 run on $(date)." >> ${logfile}
${ECHO} '#########' >> ${logfile}


# Replace files
for i in $(${FIND} ${BKUP} -type f  ! -iname "*.sastk"); do
    file=${i}
    newfile="/$(${ECHO} ${file} | ${CUT} -d'/' -f 6-)"
    ${MV} ${file} ${newfile}
done
${ECHO} "" 
${ECHO} "Files Restored" 

# Remove passwd aging
${PASSWD} -x 99999 -w 0 root
for user in $(${EGREP} '[1-9][0-9]{3,}' /etc/passwd | ${CUT} -d':' -f1);
do
        ${PASSWD} -x 99999 -w 0 "${user}" 1>> ${logfile} 2>> ${errlog}
done
${ECHO} "" 
${ECHO} "Removed password aging" 

# Remove /bin/false from /etc/passwd
${SED} -e '{
/ftp/s/false/bash/
/gdm/s/false/bash/
/:1:/,/:99:/s/\/bin\/false//
}' "/etc/passwd" > "/tmp/passwd" 2>> ${errlog}
${MV} "/tmp/passwd" "/etc/passwd" 2>> ${errlog}
${CHMOD} 0644 "/etc/passwd" 2>> ${errlog}

${ECHO} "" 
${ECHO} "Removed /bin/false from /etc/passwd" 

# Update Lilo
[ -f /etc/lilo.conf ] && ${LILO} 1>> ${logfile} 2>> ${errlog}

# Restore Original File permissions I think this should be the last thing we do.
if [ -f "${BKUP}/fileperm.bak" ];then
    ${AWK} -F: '{
        print "chmod "$1" "$4
        print "chown "$2"."$3" "$4
        system("/bin/chmod "$1" "$4)
        system("/bin/chown "$2"."$3" "$4)
    }' < "${BKUP}/fileperm.bak" 1>> ${logfile} 2>> ${errlog}
    ${RM} -rf "${BKUP}/fileperm.bak"
${ECHO} "" 
${ECHO} "Restored file permissions" 
fi

# Take care of .bash_login
[ -f /root/.bash_login.bak ] && ${MV} "/root/.bash_login.bak" "/root/.bash_login" || ${RM} "/root/.bash_login" 2>> ${errlog}

# Remove any sasrc files.
for each in "$(${GREP} -l '/etc/rc.d/rc.paths' /etc/rc.d/rc.*)"; do
${RM} "${each}" 2>> ${errlog}
done 
[ -f /etc/rc.d/rc.conf ] && ${RM} /etc/rc.d/rc.conf
[ -f /etc/rc.d/rc.paths ] && ${RM} /etc/rc.d/rc.paths

# unset anything we've exported
for i in errlog logfile BKUP LOG RC SENDMAILDIR ver version ; do
        unset ${i}
done
export PATH="${OLDPATH}"

if [ "$(${RUNLEVEL} | ${AWK} '{print $2}')" = "1" ]; then
    ${ECHO} ""
    ${CLEAR}
    quit=n
    ${CAT} << EOF
********************************************************************************
*                     SAStk removal script version ${ver}
********************************************************************************

                      SAStk removal complete

While it is unlikely, there is the possibility that some services/deamons
may still be running.
A telinit 3 will return you to Multi-user mode but we would strongly recommend
rebooting the system to be sure all services/daemons are stopped and
or restarted with your new configuration.

Once you are sure that your system is working correctly you may remove the
SAStk Backup and Log files with 'rm -rf /var/log/sastk'

EOF
    while [ "${quit}" = "n" ]; do
        ${CAT} << EOF

Choose an option from the list

1) Reboot the system
2) Halt the system
3) Enter Multi user mode
Q) Quit this script and stay in single user mode

EOF

      ${ECHO} -ne "Choose an option: .\b"
      read choice
      case ${choice} in

          1)       ${SHUTDOWN} -r now;
                   ${CLEAR};exit 0
                   ;;
          2)       ${SHUTDOWN} -h now;
                   ${CLEAR};exit 0
                   ;;
          3)       ${ECHO} "Switching to Multi user Mode."
                   ${TELINIT} 3; exit 0
                   ;;
        Q|q)       ${CLEAR};quit="y"
                   ;;
          *)       ${ECHO} -ne "Invalid choice!! \a\a"
                   ;;
     esac
   done
fi




#################
# End of Script #
#################
